"use strict";
var Status = (function () {
    function Status(synchronized) {
        if (synchronized === void 0) { synchronized = false; }
        this._synchronized = synchronized;
        this._modified = false;
        this._removed = false;
        this._fresh = !synchronized;
        this._pending = false;
    }
    Object.defineProperty(Status.prototype, "synchronized", {
        get: function () {
            return this._synchronized;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Status.prototype, "fresh", {
        get: function () {
            return this._fresh;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Status.prototype, "added", {
        get: function () {
            return !this._synchronized;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Status.prototype, "modified", {
        get: function () {
            return this._modified;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Status.prototype, "removed", {
        get: function () {
            return this._removed;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Status.prototype, "pending", {
        get: function () {
            return this._pending;
        },
        enumerable: true,
        configurable: true
    });
    Status.prototype.setDecayed = function () {
        if (!this._fresh) {
            return this;
        }
        var clone = this.clone();
        clone._fresh = false;
        return clone;
    };
    Status.prototype.setModified = function () {
        if (this._modified) {
            return this;
        }
        var clone = this.clone();
        clone._modified = true;
        return clone;
    };
    Status.prototype.setUnmodified = function () {
        if (!this._modified) {
            return this;
        }
        var clone = this.clone();
        clone._modified = false;
        return clone;
    };
    Status.prototype.setRemoved = function () {
        if (this._removed) {
            return this;
        }
        var clone = this.clone();
        clone._removed = true;
        return clone;
    };
    Status.prototype.setPending = function () {
        if (this._pending) {
            return this;
        }
        var clone = this.clone();
        clone._pending = true;
        return clone;
    };
    Status.prototype.setReady = function () {
        if (!this._pending) {
            return this;
        }
        var clone = this.clone();
        clone._pending = false;
        return clone;
    };
    Status.prototype.clone = function () {
        var clone = new Status();
        clone._synchronized = this._synchronized;
        clone._modified = this._modified;
        clone._removed = this._removed;
        clone._fresh = this._fresh;
        clone._pending = this._pending;
        return clone;
    };
    return Status;
}());
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = Status;
